
import React, { useEffect, lazy, Suspense } from 'react';
import Footer from '@/components/Footer';
import CriticalNavbar from '@/components/CriticalNavbar';
import CriticalHeroSection from '@/components/CriticalHeroSection';
import EssentialSchemaMarkup from '@/components/EssentialSchemaMarkup';
import { Helmet } from 'react-helmet';
import { useSimpleVisitor } from '@/hooks/use-simple-visitor';
import { useSimpleVisibility } from '@/hooks/useSimpleVisibility';
import { useLazyContentData } from '@/components/LazyContentLoader';

// Import critical data directly for immediate availability
import { mainServices } from '@/data/services';
import { stats } from '@/data/stats';

// Critical components loaded immediately
import ServicesSection from '@/components/ServicesSection';
import StatSection from '@/components/StatSection';
import CompanyTagline from '@/components/CompanyTagline';
import LazyContentSections from '@/components/LazyContentSections';

// Lazy-loaded heavy components for better LCP
const FounderProfile = lazy(() => import('@/components/FounderProfile'));
const GovernmentHealthRisks = lazy(() => import('@/components/GovernmentHealthRisks'));
const CoreFeatures = lazy(() => import('@/components/CoreFeatures'));

// Simple loading fallback
const ComponentLoader = () => (
  <div className="h-20 flex items-center justify-center">
    <div className="w-6 h-6 border-2 border-primary border-t-transparent rounded-full animate-spin"></div>
  </div>
);

const Index = () => {
  const { personalizedGreeting } = useSimpleVisitor();
  const shouldLoadHeavyComponents = useSimpleVisibility();
  const lazyData = useLazyContentData(shouldLoadHeavyComponents);
  
  // Static hero props with fallback for better LCP - avoid dynamic content initially
  const heroProps = {
    title: "London's Mould Removal Company", // Use static title for better LCP
    subtitle: "Certified mould experts providing professional mould treatment services across all London boroughs.",
    benefits: [
      "Expert Mould Removal with Expert Advice",
      "Safe for Families, Tenants & Pets – Eco-Friendly Methods", 
      "Certified Mould Experts You Can Rely On"
    ]
  };

  // Use personalized greeting only after initial render to avoid LCP impact
  useEffect(() => {
    if (personalizedGreeting && personalizedGreeting !== "London's Mould Removal Company") {
      // Update title after component has mounted for better LCP
      const titleElement = document.querySelector('.hero-title');
      if (titleElement) {
        titleElement.textContent = personalizedGreeting;
      }
    }
  }, [personalizedGreeting]);
  
  return (
    <>
      <Helmet>
        <link rel="canonical" href="https://mouldremovallondon.co.uk/" />
      </Helmet>
      
      <EssentialSchemaMarkup 
        businessName="AirFresh Mould Removal London - Mould Removal Company"
        description="London's mould removal company helping landlords, tenants, and homeowners restore safe, healthy homes by removing mould and improving air quality across all London boroughs."
        rating={{
          ratingValue: 4.8,
          ratingCount: 127
        }}
        pageName="Mould Removal London | Professional Services | AirFresh"
        pageDescription="Expert mould removal across London with certified specialists. We help landlords, tenants, and homeowners restore safe, healthy homes by removing mould and improving air quality."
        pageUrl="https://mouldremovallondon.co.uk/"
      />
      
      <CriticalNavbar />
      
      <main>
        <CriticalHeroSection {...heroProps} />
        
        <Suspense fallback={<ComponentLoader />}>
          <CompanyTagline />
        </Suspense>

        {/* Lazy load CoreFeatures after initial render */}
        <Suspense fallback={<ComponentLoader />}>
          <CoreFeatures />
        </Suspense>

        {/* Critical sections - load immediately */}
        <StatSection stats={stats} />
        <ServicesSection 
          title="Our Professional Mould Services in London"
          subtitle="Expert mould solutions from London's trusted mould removal company"
          services={mainServices}
          showViewAllButton={true}
        />

        {/* Lazy load FounderProfile after initial render */}
        <Suspense fallback={<ComponentLoader />}>
          <FounderProfile />
        </Suspense>

        {/* Lazy load GovernmentHealthRisks after initial render */}
        <Suspense fallback={<ComponentLoader />}>
          <GovernmentHealthRisks 
            title="Why Professional Mould Removal Matters"
            showFullContent={true}
          />
        </Suspense>

        {/* Heavy components - load only when needed */}
        <LazyContentSections 
          shouldLoad={shouldLoadHeavyComponents}
          lazyData={lazyData}
        />
      </main>
      
      <Footer />
    </>
  );
};

export default Index;
